---
title: gitea
type: docs
---

[![Source Code](https://img.shields.io/badge/gitea-source%20code-blue?logo=gitea&logoColor=white)](https://gitea.rknet.org/ansible/xoxys.gitea) [![Build Status](https://img.shields.io/drone/build/ansible/xoxys.gitea?logo=drone&server=https%3A%2F%2Fdrone.rknet.org)](https://drone.rknet.org/ansible/xoxys.gitea) [![License: MIT](https://img.shields.io/badge/license-MIT-blue.svg)](https://gitea.rknet.org/ansible/xoxys.gitea/src/branch/main/LICENSE)

Setup a [Gitea](https://gitea.io/en-us/) git server. Gitea is a community managed lightweight code hosting solution written in Go.

<!--more-->

- [Default Variables](#default-variables)
  - [gitea_access_token_expiration_time](#gitea_access_token_expiration_time)
  - [gitea_api_default_git_trees_per_page](#gitea_api_default_git_trees_per_page)
  - [gitea_api_default_paging_num](#gitea_api_default_paging_num)
  - [gitea_api_swagger_enabled](#gitea_api_swagger_enabled)
  - [gitea_attachment_allowed_types](#gitea_attachment_allowed_types)
  - [gitea_attachment_enabled](#gitea_attachment_enabled)
  - [gitea_attachment_max_files](#gitea_attachment_max_files)
  - [gitea_attachment_max_filesize](#gitea_attachment_max_filesize)
  - [gitea_avatar_federation_enabled](#gitea_avatar_federation_enabled)
  - [gitea_base_dir](#gitea_base_dir)
  - [gitea_bind_ip](#gitea_bind_ip)
  - [gitea_bind_port](#gitea_bind_port)
  - [gitea_config_dir](#gitea_config_dir)
  - [gitea_data_dir](#gitea_data_dir)
  - [gitea_db_name](#gitea_db_name)
  - [gitea_db_password](#gitea_db_password)
  - [gitea_db_port](#gitea_db_port)
  - [gitea_db_server](#gitea_db_server)
  - [gitea_db_ssl_mode](#gitea_db_ssl_mode)
  - [gitea_db_type](#gitea_db_type)
  - [gitea_db_user](#gitea_db_user)
  - [gitea_default_dependencies_enabled](#gitea_default_dependencies_enabled)
  - [gitea_default_email_notification](#gitea_default_email_notification)
  - [gitea_default_keep_email_private](#gitea_default_keep_email_private)
  - [gitea_default_org_allow_creation](#gitea_default_org_allow_creation)
  - [gitea_default_org_member_visible](#gitea_default_org_member_visible)
  - [gitea_default_org_visible](#gitea_default_org_visible)
  - [gitea_default_timetracking_enabled](#gitea_default_timetracking_enabled)
  - [gitea_extra_groups](#gitea_extra_groups)
  - [gitea_extra_links](#gitea_extra_links)
  - [gitea_extra_links_footer](#gitea_extra_links_footer)
  - [gitea_footer_show_branding](#gitea_footer_show_branding)
  - [gitea_footer_show_template_load_time](#gitea_footer_show_template_load_time)
  - [gitea_footer_show_version](#gitea_footer_show_version)
  - [gitea_git_hooks_enabled](#gitea_git_hooks_enabled)
  - [gitea_gravatar_enabled](#gitea_gravatar_enabled)
  - [gitea_gravatar_source](#gitea_gravatar_source)
  - [gitea_group](#gitea_group)
  - [gitea_install_lock](#gitea_install_lock)
  - [gitea_invalidate_refresh_tokens](#gitea_invalidate_refresh_tokens)
  - [gitea_jwt_secret](#gitea_jwt_secret)
  - [gitea_jwt_signing_algorithm](#gitea_jwt_signing_algorithm)
  - [gitea_landing_page](#gitea_landing_page)
  - [gitea_lfs_enabled](#gitea_lfs_enabled)
  - [gitea_lfs_jwt_secret](#gitea_lfs_jwt_secret)
  - [gitea_listen_address](#gitea_listen_address)
  - [gitea_log_dir](#gitea_log_dir)
  - [gitea_log_level](#gitea_log_level)
  - [gitea_login_remember_days](#gitea_login_remember_days)
  - [gitea_mail_service_enabled](#gitea_mail_service_enabled)
  - [gitea_mail_service_from](#gitea_mail_service_from)
  - [gitea_mail_subject_prefix](#gitea_mail_subject_prefix)
  - [gitea_markdown_custom_url_scheme](#gitea_markdown_custom_url_scheme)
  - [gitea_markdown_file_ext](#gitea_markdown_file_ext)
  - [gitea_markdown_hard_linebreak_enabled](#gitea_markdown_hard_linebreak_enabled)
  - [gitea_metrics_enabled](#gitea_metrics_enabled)
  - [gitea_metrics_token](#gitea_metrics_token)
  - [gitea_minimum_keysize](#gitea_minimum_keysize)
  - [gitea_minimum_keysize_check](#gitea_minimum_keysize_check)
  - [gitea_mirror_default_interval](#gitea_mirror_default_interval)
  - [gitea_mirror_min_interval](#gitea_mirror_min_interval)
  - [gitea_no_reply_address](#gitea_no_reply_address)
  - [gitea_oauth_provider_enabled](#gitea_oauth_provider_enabled)
  - [gitea_offline_mode](#gitea_offline_mode)
  - [gitea_org_creation_enabled](#gitea_org_creation_enabled)
  - [gitea_packages](#gitea_packages)
  - [gitea_password_complexity](#gitea_password_complexity)
  - [gitea_password_min_lenght](#gitea_password_min_lenght)
  - [gitea_refresh_token_expiration_time](#gitea_refresh_token_expiration_time)
  - [gitea_registration_allow_external_only](#gitea_registration_allow_external_only)
  - [gitea_registration_button_enabled](#gitea_registration_button_enabled)
  - [gitea_registration_email_confirm](#gitea_registration_email_confirm)
  - [gitea_registration_email_domain_whitelist](#gitea_registration_email_domain_whitelist)
  - [gitea_registration_enabled](#gitea_registration_enabled)
  - [gitea_repository_access_control_allow_origin](#gitea_repository_access_control_allow_origin)
  - [gitea_repository_auto_watch_on_change](#gitea_repository_auto_watch_on_change)
  - [gitea_repository_auto_watch_on_creation](#gitea_repository_auto_watch_on_creation)
  - [gitea_repository_creation_limit](#gitea_repository_creation_limit)
  - [gitea_repository_default_branch](#gitea_repository_default_branch)
  - [gitea_repository_default_license](#gitea_repository_default_license)
  - [gitea_repository_default_private](#gitea_repository_default_private)
  - [gitea_repository_default_repo_units](#gitea_repository_default_repo_units)
  - [gitea_repository_editor_line_wrap_ext](#gitea_repository_editor_line_wrap_ext)
  - [gitea_repository_force_private](#gitea_repository_force_private)
  - [gitea_repository_http_enabled](#gitea_repository_http_enabled)
  - [gitea_repository_issue_lock_reason](#gitea_repository_issue_lock_reason)
  - [gitea_repository_pr_close_keyword](#gitea_repository_pr_close_keyword)
  - [gitea_repository_pr_reopen_keyword](#gitea_repository_pr_reopen_keyword)
  - [gitea_repository_pr_wip_prefix](#gitea_repository_pr_wip_prefix)
  - [gitea_repository_push_create_org_enabled](#gitea_repository_push_create_org_enabled)
  - [gitea_repository_push_create_user_enabled](#gitea_repository_push_create_user_enabled)
  - [gitea_repository_upload_allowed_types](#gitea_repository_upload_allowed_types)
  - [gitea_repository_upload_enabled](#gitea_repository_upload_enabled)
  - [gitea_repository_upload_max_files](#gitea_repository_upload_max_files)
  - [gitea_repository_upload_max_filesize](#gitea_repository_upload_max_filesize)
  - [gitea_repository_use_compat_ssh_uri](#gitea_repository_use_compat_ssh_uri)
  - [gitea_run_dir](#gitea_run_dir)
  - [gitea_run_mode](#gitea_run_mode)
  - [gitea_secret](#gitea_secret)
  - [gitea_selinux_fcontext](#gitea_selinux_fcontext)
  - [gitea_selinux_restorecon](#gitea_selinux_restorecon)
  - [gitea_session_cookie_name](#gitea_session_cookie_name)
  - [gitea_session_cookie_secure](#gitea_session_cookie_secure)
  - [gitea_session_enable_set_cookie](#gitea_session_enable_set_cookie)
  - [gitea_session_provider](#gitea_session_provider)
  - [gitea_session_provider_config](#gitea_session_provider_config)
  - [gitea_session_session_life_time](#gitea_session_session_life_time)
  - [gitea_ssh_enabled](#gitea_ssh_enabled)
  - [gitea_template_dir](#gitea_template_dir)
  - [gitea_tls_cert_path](#gitea_tls_cert_path)
  - [gitea_tls_cert_source](#gitea_tls_cert_source)
  - [gitea_tls_enabled](#gitea_tls_enabled)
  - [gitea_tls_key_path](#gitea_tls_key_path)
  - [gitea_tls_key_source](#gitea_tls_key_source)
  - [gitea_token](#gitea_token)
  - [gitea_ui_admin_notice_paging_num](#gitea_ui_admin_notice_paging_num)
  - [gitea_ui_admin_org_paging_num](#gitea_ui_admin_org_paging_num)
  - [gitea_ui_admin_repo_paging_num](#gitea_ui_admin_repo_paging_num)
  - [gitea_ui_admin_user_paging_num](#gitea_ui_admin_user_paging_num)
  - [gitea_ui_code_comment_lines](#gitea_ui_code_comment_lines)
  - [gitea_ui_explore_paging_num](#gitea_ui_explore_paging_num)
  - [gitea_ui_feed_commit_num](#gitea_ui_feed_commit_num)
  - [gitea_ui_graph_commit_num](#gitea_ui_graph_commit_num)
  - [gitea_ui_issue_paging_num](#gitea_ui_issue_paging_num)
  - [gitea_ui_reaction](#gitea_ui_reaction)
  - [gitea_ui_search_repo_description](#gitea_ui_search_repo_description)
  - [gitea_ui_show_full_name](#gitea_ui_show_full_name)
  - [gitea_ui_show_user_email](#gitea_ui_show_user_email)
  - [gitea_ui_user_repo_paging_num](#gitea_ui_user_repo_paging_num)
  - [gitea_user](#gitea_user)
  - [gitea_user_home](#gitea_user_home)
  - [gitea_version](#gitea_version)
  - [gitea_webhook_allowed_host_list](#gitea_webhook_allowed_host_list)
- [Discovered Tags](#discovered-tags)
- [Dependencies](#dependencies)

---

## Default Variables

### gitea_access_token_expiration_time

#### Default value

```YAML
gitea_access_token_expiration_time: 3600
```

### gitea_api_default_git_trees_per_page

#### Default value

```YAML
gitea_api_default_git_trees_per_page: 1000
```

### gitea_api_default_paging_num

#### Default value

```YAML
gitea_api_default_paging_num: 30
```

### gitea_api_swagger_enabled

#### Default value

```YAML
gitea_api_swagger_enabled: true
```

### gitea_attachment_allowed_types

#### Default value

```YAML
gitea_attachment_allowed_types:
  - image/jpeg
  - image/png
  - application/zip
  - application/gzip
```

### gitea_attachment_enabled

#### Default value

```YAML
gitea_attachment_enabled: true
```

### gitea_attachment_max_files

#### Default value

```YAML
gitea_attachment_max_files: 5
```

### gitea_attachment_max_filesize

#### Default value

```YAML
gitea_attachment_max_filesize: 3
```

### gitea_avatar_federation_enabled

#### Default value

```YAML
gitea_avatar_federation_enabled: false
```

### gitea_base_dir

#### Default value

```YAML
gitea_base_dir: /opt/gitea
```

### gitea_bind_ip

#### Default value

```YAML
gitea_bind_ip: 127.0.0.1
```

### gitea_bind_port

#### Default value

```YAML
gitea_bind_port: 61000
```

### gitea_config_dir

#### Default value

```YAML
gitea_config_dir: '{{ gitea_base_dir }}/custom/conf'
```

### gitea_data_dir

#### Default value

```YAML
gitea_data_dir: '{{ gitea_base_dir }}/data'
```

### gitea_db_name

#### Default value

```YAML
gitea_db_name: gitea
```

### gitea_db_password

#### Default value

```YAML
gitea_db_password: secure
```

### gitea_db_port

#### Default value

```YAML
gitea_db_port: 5432
```

### gitea_db_server

#### Default value

```YAML
gitea_db_server: localhost
```

### gitea_db_ssl_mode

#### Default value

```YAML
gitea_db_ssl_mode: disable
```

### gitea_db_type

#### Default value

```YAML
gitea_db_type: sqlite
```

### gitea_db_user

#### Default value

```YAML
gitea_db_user: pggitea
```

### gitea_default_dependencies_enabled

#### Default value

```YAML
gitea_default_dependencies_enabled: true
```

### gitea_default_email_notification

Default configuration for email notifications for users (user configurable). Options: `enabled`, `onmention`, `disabled`.

#### Default value

```YAML
gitea_default_email_notification: enabled
```

### gitea_default_keep_email_private

#### Default value

```YAML
gitea_default_keep_email_private: true
```

### gitea_default_org_allow_creation

#### Default value

```YAML
gitea_default_org_allow_creation: true
```

### gitea_default_org_member_visible

#### Default value

```YAML
gitea_default_org_member_visible: false
```

### gitea_default_org_visible

#### Default value

```YAML
gitea_default_org_visible: public
```

### gitea_default_timetracking_enabled

#### Default value

```YAML
gitea_default_timetracking_enabled: true
```

### gitea_extra_groups

#### Default value

```YAML
gitea_extra_groups: []
```

### gitea_extra_links

#### Default value

```YAML
gitea_extra_links: []
```

### gitea_extra_links_footer

Add custom links e.g. legal notice to gitea footer.

#### Default value

```YAML
gitea_extra_links_footer: []
```

#### Example usage

```YAML
gitea_extra_links_footer:
  - name: Legal Notice
    href: https://example.com/legal_notice
```

### gitea_footer_show_branding

#### Default value

```YAML
gitea_footer_show_branding: false
```

### gitea_footer_show_template_load_time

#### Default value

```YAML
gitea_footer_show_template_load_time: false
```

### gitea_footer_show_version

#### Default value

```YAML
gitea_footer_show_version: false
```

### gitea_git_hooks_enabled

#### Default value

```YAML
gitea_git_hooks_enabled: true
```

### gitea_gravatar_enabled

#### Default value

```YAML
gitea_gravatar_enabled: false
```

### gitea_gravatar_source

#### Default value

```YAML
gitea_gravatar_source: gravatar
```

### gitea_group

#### Default value

```YAML
gitea_group: '{{ gitea_user }}'
```

### gitea_install_lock

#### Default value

```YAML
gitea_install_lock: true
```

### gitea_invalidate_refresh_tokens

#### Default value

```YAML
gitea_invalidate_refresh_tokens: false
```

### gitea_jwt_secret

OAuth2 authentication secret for access and refresh tokens. Should be replaced by your own secret. Only works if `gitea_jwt_signing_algorithm` is set to HS256, HS384 or HS512.

#### Example usage

```YAML
gitea_jwt_secret: Bk0yK7Y9g_p56v86KaHqjSbxvNvu3SbKoOdOt2ZcXvU
```

### gitea_jwt_signing_algorithm

#### Default value

```YAML
gitea_jwt_signing_algorithm: RS256
```

### gitea_landing_page

#### Default value

```YAML
gitea_landing_page: explore
```

### gitea_lfs_enabled

#### Default value

```YAML
gitea_lfs_enabled: false
```

### gitea_lfs_jwt_secret

#### Default value

```YAML
gitea_lfs_jwt_secret: gitea_lfs_jwt_secret
```

### gitea_listen_address

#### Default value

```YAML
gitea_listen_address: http://gitea.example.com
```

### gitea_log_dir

#### Default value

```YAML
gitea_log_dir: '{{ gitea_base_dir }}/log'
```

### gitea_log_level

#### Default value

```YAML
gitea_log_level: Info
```

### gitea_login_remember_days

#### Default value

```YAML
gitea_login_remember_days: 7
```

### gitea_mail_service_enabled

#### Default value

```YAML
gitea_mail_service_enabled: false
```

### gitea_mail_service_from

#### Default value

```YAML
gitea_mail_service_from: '"System" <systemmail@example.com>'
```

### gitea_mail_subject_prefix

Prefix displayed before subject in mail.

### gitea_markdown_custom_url_scheme

#### Default value

```YAML
gitea_markdown_custom_url_scheme: []
```

### gitea_markdown_file_ext

#### Default value

```YAML
gitea_markdown_file_ext:
  - .md
  - .markdown
  - .mdown
  - .mkd
```

### gitea_markdown_hard_linebreak_enabled

#### Default value

```YAML
gitea_markdown_hard_linebreak_enabled: false
```

### gitea_metrics_enabled

#### Default value

```YAML
gitea_metrics_enabled: false
```

### gitea_metrics_token

If you want to add authorization, specify a token here.

### gitea_minimum_keysize

Define allowed algorithms and their minimum key length (use -1 to disable a type).

#### Default value

```YAML
gitea_minimum_keysize:
  - name: ED25519
    size: 256
  - name: ECDSA
    size: 256
  - name: RSA
    size: 2048
  - name: DSA
    size: -1
```

### gitea_minimum_keysize_check

Indicate whether to check minimum key size with corresponding type.

#### Default value

```YAML
gitea_minimum_keysize_check: false
```

### gitea_mirror_default_interval

#### Default value

```YAML
gitea_mirror_default_interval: 8h
```

### gitea_mirror_min_interval

#### Default value

```YAML
gitea_mirror_min_interval: 10h
```

### gitea_no_reply_address

#### Default value

```YAML
gitea_no_reply_address: noreply@example.org
```

### gitea_oauth_provider_enabled

#### Default value

```YAML
gitea_oauth_provider_enabled: false
```

### gitea_offline_mode

#### Default value

```YAML
gitea_offline_mode: false
```

### gitea_org_creation_enabled

Allow regular (non-admin) users to create organizations.

#### Default value

```YAML
gitea_org_creation_enabled: true
```

### gitea_packages

#### Default value

```YAML
gitea_packages:
  - git
```

### gitea_password_complexity

If left empty or no valid values are specified, the default values `lower,upper,digit,spec` will be used. Use `off` to disable checking.

#### Default value

```YAML
gitea_password_complexity:
  - lower
  - upper
  - digit
  - spec
```

### gitea_password_min_lenght

#### Default value

```YAML
gitea_password_min_lenght: 8
```

### gitea_refresh_token_expiration_time

#### Default value

```YAML
gitea_refresh_token_expiration_time: 730
```

### gitea_registration_allow_external_only

#### Default value

```YAML
gitea_registration_allow_external_only: false
```

### gitea_registration_button_enabled

#### Default value

```YAML
gitea_registration_button_enabled: true
```

### gitea_registration_email_confirm

#### Default value

```YAML
gitea_registration_email_confirm: false
```

### gitea_registration_email_domain_whitelist

#### Default value

```YAML
gitea_registration_email_domain_whitelist: []
```

### gitea_registration_enabled

#### Default value

```YAML
gitea_registration_enabled: false
```

### gitea_repository_access_control_allow_origin

Value for Access-Control-Allow-Origin header, default unset. WARNING: This maybe harmful to you website if you do not give it a right value!

### gitea_repository_auto_watch_on_change

#### Default value

```YAML
gitea_repository_auto_watch_on_change: false
```

### gitea_repository_auto_watch_on_creation

#### Default value

```YAML
gitea_repository_auto_watch_on_creation: false
```

### gitea_repository_creation_limit

#### Default value

```YAML
gitea_repository_creation_limit: -1
```

### gitea_repository_default_branch

#### Default value

```YAML
gitea_repository_default_branch: main
```

### gitea_repository_default_license

#### Default value

```YAML
gitea_repository_default_license:
  - Apache License 2.0
  - MIT Licensei
```

### gitea_repository_default_private

#### Default value

```YAML
gitea_repository_default_private: last
```

### gitea_repository_default_repo_units

#### Default value

```YAML
gitea_repository_default_repo_units:
  - repo.code
  - repo.releases
  - repo.issues
  - repo.pulls
  - repo.wiki
  - repo.projects
```

### gitea_repository_editor_line_wrap_ext

Comma-separated list of file extensions for which lines should be wrapped in the CodeMirror editor. To line wrap files without an extension, just put a comma.

#### Default value

```YAML
gitea_repository_editor_line_wrap_ext:
  - .txt
  - .md
  - .markdown
  - .mdown
  - .mkd
```

### gitea_repository_force_private

#### Default value

```YAML
gitea_repository_force_private: false
```

### gitea_repository_http_enabled

#### Default value

```YAML
gitea_repository_http_enabled: true
```

### gitea_repository_issue_lock_reason

List of reasons why a Pull Request or Issue can be locked.

#### Default value

```YAML
gitea_repository_issue_lock_reason:
  - Too heated
  - Off-topic
  - Resolved
  - Spam
```

### gitea_repository_pr_close_keyword

#### Default value

```YAML
gitea_repository_pr_close_keyword:
  - close
  - closes
  - closed
  - fix
  - fixes
  - fixed
  - resolve
  - resolves
  - resolved
```

### gitea_repository_pr_reopen_keyword

#### Default value

```YAML
gitea_repository_pr_reopen_keyword:
  - reopen
  - reopens
  - reopened
```

### gitea_repository_pr_wip_prefix

List of prefixes used in Pull Request title to mark them as Work In Progress.

#### Default value

```YAML
gitea_repository_pr_wip_prefix:
  - 'WIP:'
  - '[WIP]'
```

### gitea_repository_push_create_org_enabled

#### Default value

```YAML
gitea_repository_push_create_org_enabled: false
```

### gitea_repository_push_create_user_enabled

#### Default value

```YAML
gitea_repository_push_create_user_enabled: false
```

### gitea_repository_upload_allowed_types

One or more allowed types, e.g. image/jpeg|image/png. Default allows any file type.

#### Default value

```YAML
gitea_repository_upload_allowed_types: []
```

### gitea_repository_upload_enabled

#### Default value

```YAML
gitea_repository_upload_enabled: true
```

### gitea_repository_upload_max_files

#### Default value

```YAML
gitea_repository_upload_max_files: 5
```

### gitea_repository_upload_max_filesize

#### Default value

```YAML
gitea_repository_upload_max_filesize: 3
```

### gitea_repository_use_compat_ssh_uri

Force ssh:// clone url instead of scp-style uri when default SSH port is used

#### Default value

```YAML
gitea_repository_use_compat_ssh_uri: false
```

### gitea_run_dir

#### Default value

```YAML
gitea_run_dir: '{{ gitea_base_dir }}/run'
```

### gitea_run_mode

#### Default value

```YAML
gitea_run_mode: prod
```

### gitea_secret

Should be replaced by your own secret.

#### Default value

```YAML
gitea_secret: 1234567ABCDEFG
```

### gitea_selinux_fcontext

#### Default value

```YAML
gitea_selinux_fcontext:
  - target: '{{ gitea_log_dir }}(/.*)?'
    setype: var_log_t
```

### gitea_selinux_restorecon

#### Default value

```YAML
gitea_selinux_restorecon:
  - -ir {{ gitea_log_dir }}
```

### gitea_session_cookie_name

#### Default value

```YAML
gitea_session_cookie_name: i_like_gitea
```

### gitea_session_cookie_secure

#### Default value

```YAML
gitea_session_cookie_secure: false
```

### gitea_session_enable_set_cookie

#### Default value

```YAML
gitea_session_enable_set_cookie: true
```

### gitea_session_provider

#### Default value

```YAML
gitea_session_provider: memory
```

### gitea_session_provider_config

#### Default value

```YAML
gitea_session_provider_config: data/sessions
```

### gitea_session_session_life_time

#### Default value

```YAML
gitea_session_session_life_time: 86400
```

### gitea_ssh_enabled

#### Default value

```YAML
gitea_ssh_enabled: true
```

### gitea_template_dir

#### Default value

```YAML
gitea_template_dir: '{{ gitea_base_dir }}/custom/templates'
```

### gitea_tls_cert_path

#### Default value

```YAML
gitea_tls_cert_path: '{{ gitea_base_dir }}/tls/certs/mycert.pem'
```

### gitea_tls_cert_source

#### Default value

```YAML
gitea_tls_cert_source: mycert.pem
```

### gitea_tls_enabled

#### Default value

```YAML
gitea_tls_enabled: false
```

### gitea_tls_key_path

#### Default value

```YAML
gitea_tls_key_path: '{{ gitea_base_dir }}/tls/private/mykey.pem'
```

### gitea_tls_key_source

#### Default value

```YAML
gitea_tls_key_source: mykey.pem
```

### gitea_token

Should be replaced by your own secret.

#### Default value

```YAML
gitea_token: akslkaldasasifiuvsiasfa7s7f8as7f8asd
```

### gitea_ui_admin_notice_paging_num

#### Default value

```YAML
gitea_ui_admin_notice_paging_num: 25
```

### gitea_ui_admin_org_paging_num

#### Default value

```YAML
gitea_ui_admin_org_paging_num: 50
```

### gitea_ui_admin_repo_paging_num

#### Default value

```YAML
gitea_ui_admin_repo_paging_num: 50
```

### gitea_ui_admin_user_paging_num

#### Default value

```YAML
gitea_ui_admin_user_paging_num: 50
```

### gitea_ui_code_comment_lines

#### Default value

```YAML
gitea_ui_code_comment_lines: 4
```

### gitea_ui_explore_paging_num

#### Default value

```YAML
gitea_ui_explore_paging_num: 20
```

### gitea_ui_feed_commit_num

#### Default value

```YAML
gitea_ui_feed_commit_num: 5
```

### gitea_ui_graph_commit_num

#### Default value

```YAML
gitea_ui_graph_commit_num: 100
```

### gitea_ui_issue_paging_num

#### Default value

```YAML
gitea_ui_issue_paging_num: 10
```

### gitea_ui_reaction

All available reactions. Allow users react with different emojis. See https://gitea.com/gitea/gitea.com/issues/8.

#### Default value

```YAML
gitea_ui_reaction:
  - 1
  - -1
  - laugh
  - hooray
  - confused
  - heart
  - rocket
  - eyes
```

### gitea_ui_search_repo_description

#### Default value

```YAML
gitea_ui_search_repo_description: true
```

### gitea_ui_show_full_name

#### Default value

```YAML
gitea_ui_show_full_name: false
```

### gitea_ui_show_user_email

#### Default value

```YAML
gitea_ui_show_user_email: true
```

### gitea_ui_user_repo_paging_num

#### Default value

```YAML
gitea_ui_user_repo_paging_num: 15
```

### gitea_user

#### Default value

```YAML
gitea_user: gitea_adm
```

### gitea_user_home

#### Default value

```YAML
gitea_user_home: /home/{{ gitea_user }}
```

### gitea_version

#### Default value

```YAML
gitea_version: 1.16.1
```

### gitea_webhook_allowed_host_list

#### Default value

```YAML
gitea_webhook_allowed_host_list:
  - external
```

## Discovered Tags

tls_renewal
: &nbsp;


## Dependencies

None.
